"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.decompress = void 0;
/**
 * Decompress level data
 * @internal
 * @packageDocumentation
 */
const isNode_1 = __importDefault(require("./isNode"));
const crypto_1 = require("./crypto");
const node_flate_1 = require("./node-flate");
/**
 * Creates a Uint8Array from a string
 * @param dat The data to convert to a byte array
 * @returns A Uint8Array from the ASCII string
 * @internal
 */
const strToU8 = (dat) => {
    const out = new Uint8Array(dat.length);
    for (let i = 0; i < dat.length; ++i)
        out[i] = dat.charCodeAt(i);
    return out;
};
/**
 * Decompresses data of an arbitrary type from the Geometry Dash servers
 * @param data The Base64, compressed data to decompress
 * @returns The source string data
 * @internal
 */
const decompress = async (data) => {
    const resultBytes = await node_flate_1.decompress(isNode_1.default ? Buffer.from(data, 'base64') : strToU8(crypto_1.gdDecodeBase64(data)));
    let out = '';
    for (const byte of resultBytes)
        out += String.fromCharCode(byte);
    return out;
};
exports.decompress = decompress;
